<?php

return function (
    $redirect = '/',
    $return = true,
    $badLoginError = 'Invalid credentials'
) {
    return [
        'POST' => function (string $username, string $password) use ($badLoginError, $redirect, $return) {
            $user = wp_signon([
                'user_login' => $username,
                'user_password' => $password,
                'remember' => true
            ]);

            if ($user instanceof WP_Error)
                $user = false;

            if ($user) {
                wp_clear_auth_cookie();
                wp_set_current_user($user->data->ID);
                wp_set_auth_cookie($user->data->ID);

                $dest = ($return and isset($_GET['return_to']))
                    ? $_GET['return_to'] : $redirect;

                return $dest;
            } else {
                return [
                    'error' => $badLoginError,
                    'state.username' => (string) $username
                ];
            }
        },
        'GET?signout' => function () {
            wp_destroy_current_session();
            wp_clear_auth_cookie();
            wp_set_current_user(0);

            return true;
        }
    ];
};
